/*----------------------------------------------------------------------------
 * Name     : main.c
 * Purpose  : 
 * Note(s)  : 
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2012 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include    <stdio.h>
#include		<math.h>
#include    <string.h>
#include    "main.h"
#include    "timer.h"
#include    "lcm.h"
#include    "led.h"
#include    "button.h"
#include		"bc3603.h"
#include		"bc3603spi.h"
#include		"bc3603test.h"
#include		"bch.h"
#include		"rf_parameter.h"


// <<< Use Configuration Wizard in Context Menu >>>

//	<h> MCU Sleep Mode Configuration
//		<o> MCU Mode Select
//			<0=> Normal
//			<1=> Sleep
//			<2=> Deep Sleep 1
//			<3=> Deep Sleep 2
#define _MCU_SLEEP_MODE_			(0)
//	</h>

/*----------------------------------------------
							Main Flag Definition
 ----------------------------------------------*/
union
{
	u16	value;
	struct
	{
		u16	button_change: 1;						// button flag
		u16 lcm_updata_falg:1;					// LCM need to updata flag
		u16	rf_wor:1;								// RF WOR flag
    u16:15;		
	}bits;
}mflag;

/*----------------------------------------------
					RF working parameter Definition
 ----------------------------------------------*/
struct __attribute__((packed))
{
	// RF parameter
	u8	tx_payload_len;
	u8	rx_payload_len;
	u8*	p_txbuf;
	u8*	p_rxbuf;
	
	// Proc parameter
	u8	rf_step;
	u16	tx_success_number;
	u16	tx_fail_number;
	u16	rx_success_number;
	u16	rx_detect_number;
	u16 rx_wakeup_number;
	u16	rx_fail_number;
	u8	rx_rcv_rssi;
	u8	rx_env_rssi;
}  RadioParam;


u32   TimePeriod;
u16   TimePeriod_EnvRSSI;
u8		key_status;

u8		IRQStatus;
u8		TxPayload[256],RxPayload[256];
u8		temp_sync[_SYNCWORD_WIDTH_];
u8		temp_bch_sync[_SYNCWORD_WIDTH_];

u32   cal_rxap_min_value;

u32 cal_wor_min_rxap_us(void);

/*----------------------------------------------------------------------------
  Main Program
 *----------------------------------------------------------------------------*/
int main (void)
{
	u8	temp;
	ATR_InitTypeDef ATR_Init;
	
	/* ----------------------- System initial ------------------------ */
	CKCU_Configuration();
	MCU_gpio_Configuration();
	SystickConfigure();
#if (_RETARGET == 1)
	RETARGET_Configuration();
#endif	
#if (_MCU_SLEEP_MODE_ != 0)
	BTN_WakeupConfig(ENABLE);		
	EXTI_WakeupEventIntConfig(ENABLE);
#endif
	
	/* timer 1ms-flag initial */
	timer_operate.bits.t1ms = FALSE;
	
	/* ------------------------ LCM initial ------------------------- */
	lcm_bus_configure();
	lcm_configure();
	lcm_put_map((u8 *)BestComm_Logo);
	lcm_put8x16_string((sc8 *)"BC3603",0,10,DSP_NORMAL);
	lcm_put8x16_string((sc8 *)" Demo ",1,10,DSP_NORMAL);
	lcm_put8x16_string((sc8 *)"Ver1.0",2,10,DSP_NORMAL);
	lcm_put6x8_string((sc8 *)"22/12/12",6,13,DSP_NORMAL);	
	
	/* --------------- LED/Button IO/Time Base initial --------------- */ 
	BTN_InterfaceConfigure();	
	LED_InterfaceConfigure();
	
	/* ----------------------- BC3603 initial ----------------------- */ 
	/* BC3603 Interface configuration */
	BC3603_InterfaceConfigure();
	/* BC3603 default register configuration */
	if( BC3603_DeInit() != SUCCESS)
	{
		lcm_put8x16_string((sc8 *)"RF DeInit Error",0,0,DSP_NORMAL);
		while(1) delay_ms(100);
	}	
	/* BC3603 RF parameter configuration */
	if( BC3603_Initial() != SUCCESS)
	{
		lcm_put8x16_string((sc8 *)"RF Initial Error",0,0,DSP_NORMAL);
		while(1) delay_ms(100);
	}	
	/* reset variable */
	mflag.bits.button_change			 = 0;
	mflag.bits.rf_wor							 = 0;
	mflag.bits.lcm_updata_falg		 = 0;
	RadioParam.rf_step 						 = 0;
	RadioParam.rx_success_number	 = 0;
	RadioParam.rx_fail_number			 = 0;
	RadioParam.rx_env_rssi				 = 120;
	RadioParam.rx_rcv_rssi				 = 0;
	
	/* ---------------------- LCM display delay ---------------------- */ 
  /* delay 1s */
	delay_ms(1000);
	lcm_clear();
	LCM_Display_Init();
	
	/* ---------------------------- Loop ---------------------------- */ 
	while(1)
	{
		/* ------------------- Timer PROC ------------------- */ 
		if(timer_operate.bits.t1ms)
		{
			/* common */
			timer_operate.bits.t1ms = FALSE;
			if(TimePeriod) TimePeriod--;		
			/* scan button */
			mflag.bits.button_change = BTN_ScanButtonStatus();
			/* LED PROC */
			LEDProcess_ms();
		}	
		
		/* -------------------- KEY PROC -------------------- */ 
		if(mflag.bits.button_change)
		{
			mflag.bits.button_change = FALSE;
			key_status = BTN_GetButtonStatus();
			switch(key_status)
			{
				case Key1:
				case Key2:
				case Key3:
				case Key4:
					if(mflag.bits.rf_wor)
					{
						/* ---------------- STOP WOR ---------------- */ 
						mflag.bits.rf_wor						 	 = 0;
						/* RF step reset */
						RadioParam.rf_step						 = 0;
						/* disable ATR */
						BC3603_ATRControl(DISABLE);
						/* RF enter light sleep */
						BC3603_EnterLightSleep();							
						/* LCM updata */
						mflag.bits.lcm_updata_falg = true;						
					}
					else
					{
						/* ---------------- START WOR ---------------- */ 
						mflag.bits.rf_wor						 	 = 1;
						/* RF step to start */
						RadioParam.rf_step						 = 1;
						/* ---------------- Reset counter ---------------- */ 
						RadioParam.rx_success_number	 = 0;
						RadioParam.rx_fail_number			 = 0;
						RadioParam.rx_env_rssi				 = 0;
						RadioParam.rx_rcv_rssi				 = 0;
						RadioParam.rx_detect_number		 = 0;
						RadioParam.rx_wakeup_number		 = 0;
						/* LCM updata */
						mflag.bits.lcm_updata_falg = true;	
						/* fot test */
						BC3603_SetGIOFunction(RF_GIO3,RF_GIO_ELNACO);
					}
					break;
				
				default:
					break;
			}
		}
		
		/* -------------------- RF PROC -------------------- */ 
		/* RF STEP */
		switch(RadioParam.rf_step)
		{
			case 1:
				/* RF enter light sleep */
				BC3603_EnterLightSleep();		
				/* wait crystal ready */
				BC3603_WaitCrystalReady();
			
				/* set RF RX IRQ enable */
				BC3603_IRQConfig(0xFF,DISABLE);
				BC3603_IRQConfig(IRQ_RXDETIE|IRQ_ATRCTIE,ENABLE);
			
				/* set RF RX detect type */
				BC3603_SetReceiverDetectEvent(DET_SYNCWORD);
			
				/* reset rf fifo point */
				BC3603_ResetRxFIFOPosition();
				/* set RX payload length */
				RadioParam.rx_payload_len = _RECEIVER_PDLEN_;
				RadioParam.p_rxbuf = RxPayload;
				BC3603_SetReceiverLength(RadioParam.rx_payload_len);		
				memset(RadioParam.p_rxbuf,0,RadioParam.rx_payload_len);			
			
				/* set RF RX SYNC to preamble type */
				#if ((_TX_PREAMBLE_CLASS_ != 1) && (_TX_PREAMBLE_CLASS_ != 3))
					#error "In WOR mode, Preamble pattern can't be config to auto"
				#endif
				#if (_TX_PREAMBLE_CLASS_==1)
				for(temp=0;temp<_SYNCWORD_WIDTH_;temp++)
				{
					temp_sync[temp] = _TX_PREAMBLE_PATTERN_&0xFF;
				}		
				#endif
				#if (_TX_PREAMBLE_CLASS_==3)
				for(temp=0;temp<_SYNCWORD_WIDTH_;temp=temp+2)
				{
					temp_sync[temp] = _TX_PREAMBLE_PATTERN_&0xFF;
					temp_sync[temp+1] = (_TX_PREAMBLE_PATTERN_>>8)&0xFF;
				}			
				#endif
				BC3603_SetSyncWord(temp_sync,_SYNCWORD_WIDTH_);
			
				/* cal rxap min time */
				cal_rxap_min_value = cal_wor_min_rxap_us();
				
				/* set ATR mode config */
				ATR_Init.Mode						= (RF_ATRM_Enum)_ATR_MD_SEL_;
				ATR_Init.ClockSource		= ATRCKS_LIRC;
				ATR_Init.Prescaler			= (RF_ATRCKD_Enum)_ATR_CLK_SEL_;
				ATR_Init.CycleCounter   = _ATR_CYC_*1000UL;
				BC3603_ATRConfig(&ATR_Init);
				
				if(cal_rxap_min_value>_ATRRXAP_TIME_)
					BC3603_SetWORPeriod(cal_rxap_min_value,_ATRRXEP_TIME_*1000UL);
				else
					BC3603_SetWORPeriod(_ATRRXAP_TIME_,_ATRRXEP_TIME_*1000UL);
				
				/* enable ATR */
				BC3603_ATRControl(ENABLE);
				
			  /* next step */
				RadioParam.rf_step++;
				break;
			
			case 2:
				/* start WOR proc */
				BC3603_EnterIdleMode();
				/* next step */
				RadioParam.rf_step++;			
				break;
			
			case 3:
				// waitting detect
				if(IRQStatus & (IRQ_RXDETIF|IRQ_ATRCTIF))
				{
					if(IRQStatus & IRQ_ATRCTIF)
					{
						RadioParam.rx_wakeup_number++;
						IRQStatus &= ~(IRQ_ATRCTIF);
						/* LCM updata */
						mflag.bits.lcm_updata_falg = true;	
					}
					
					if(IRQStatus & IRQ_RXDETIF)
					{
						RadioParam.rx_detect_number++;
						
						/* delay 200us */
						delay_us(200);
						
						/* disable ATR */
						BC3603_ATRControl(DISABLE);
						/* RF enter light sleep */
						BC3603_EnterLightSleep();
						/* wait crystal ready */
						BC3603_WaitCrystalReady();
						
						/* Reset RF RX FIFO */
						BC3603_ResetRxFIFOPosition();
						
						/* set RF RX IRQ enable */
						BC3603_IRQConfig(0xFF,DISABLE);
						BC3603_IRQConfig(IRQ_RXCMPIE|IRQ_RXERRIE,ENABLE);
						IRQStatus = 0;
						
						/* set real SYNC */
						*((u16 *)(&temp_sync[0])) = _SYNCWORD_LOW_ & 0xFFFF;
						*((u16 *)(&temp_sync[2])) = _SYNCWORD_LOW_ >> 16;
						*((u16 *)(&temp_sync[4])) = _SYNCWORD_HIGH_ & 0xFFFF;
						*((u16 *)(&temp_sync[6])) = _SYNCWORD_HIGH_ >> 16;
						#if	(_SYNCWORD_BCH_ == 1)
						BCH_SyncwordCalculate((RF_SYNCLEN_Enum)_SYNCWORD_WIDTH_,temp_sync,temp_bch_sync);
						BC3603_SetSyncWord(temp_bch_sync,_SYNCWORD_WIDTH_);
						#else
						BC3603_SetSyncWord(temp_sync,_SYNCWORD_WIDTH_);	
						#endif			
						
						/* start RX proc */
						BC3603_EnterReceiver();
						/* set RX time-out period */
						TimePeriod = 1.2*_ATR_CYC_;
						/* next step */
						RadioParam.rf_step++;						
					}
				}
				
				break;
			
			case 4:
				/* wait IRQ arrival */
				if(IRQStatus & (IRQ_RXCMPIF|IRQ_RXERRIF))
				{
					/* RF enter light sleep */
					BC3603_EnterLightSleep();	
					/* read data */
					RadioParam.rx_payload_len = BC3603_ReadReceiverPayload(RadioParam.p_rxbuf);
					/* read rssi result */
					RadioParam.rx_rcv_rssi = BC3603_GetSYNCRSSIValue();
					
					/* RX ERROR PROC */
					if(IRQStatus & IRQ_RXERRIE)
					{
						RadioParam.rx_fail_number++;
						/* LED2 flash */
						LED_EnableFlag_ms(LED2,50);
					}
					/* RX DONE PROC */
					else
					{
						/* check data */
						if(!is_same_data(RadioParam.p_rxbuf,(u8*)PN9Patten,RadioParam.rx_payload_len))
						{
							/* RX ERROR PROC */
							RadioParam.rx_fail_number++;
							/* LED2 flash */
							LED_EnableFlag_ms(LED2,50);
						}
						else
						{
							/* SUCCESS PROC */
							RadioParam.rx_success_number++;
							/* LED1 flash */
							LED_EnableFlag_ms(LED1,50);
						}
					}
					
					/* clear IRQ status */
					IRQStatus	&= ~(IRQ_RXCMPIE|IRQ_RXERRIE|IRQ_ATRCTIE|IRQ_RXDETIE);
					/* LCM updata */
					mflag.bits.lcm_updata_falg = 1;			
					/* return step1 */
					RadioParam.rf_step = 1;
					/* LCM updata */
					mflag.bits.lcm_updata_falg = true;	
				}
				
				/* RX time-out */
				if(TimePeriod == 0)
				{
					/* RF enter light sleep */
					BC3603_EnterLightSleep();	
					/* return step1 */
					RadioParam.rf_step = 1;
					/* LCM updata */
					mflag.bits.lcm_updata_falg = true;	
				}
				break;
			
			default:
				break;
		}
		
		/* RF IRQ check */
		if(BC3603_IRQLineStatus() == SET)
		{
			/* read IRQ status */
			IRQStatus = BC3603_GetIRQFlag();
			/* clear IRQ status */
			BC3603_ClearIRQFlag(IRQStatus);
		}			
		
		/* -------------------- LCM PROC -------------------- */ 
		if(mflag.bits.lcm_updata_falg)
		{
			mflag.bits.lcm_updata_falg = 0;
			/* updata LCM display */
			LCM_Display_Updata();
		}
		
	}
}
/*****************************************************************************************************
* @brief  carrier test item initial.
* @retval None
*******************************************************************************************************/
ErrStatus BC3603_Initial(void)	
{
	u8							Syncw[SYNCWORD_MAX_SIZE];
	u8							SyncBch[SYNCWORD_MAX_SIZE];
	RF_InitTypeDef	RF_InitStruct;
	
	/* Config by <rf_parameter.h> */
	RF_InitStruct.RFBand = (RF_BAND_Enum)_RF_FREQ_BAND_;
	RF_InitStruct.Frequency = _RF_FREQUENCY_;
	RF_InitStruct.TxPower = (RF_TXPWR_Enum)_RF_TX_POWER_;
	RF_InitStruct.DataRate = (RF_DATARATE_Enum)_RF_DATA_RATE_;
	RF_InitStruct.TxPremLength = _TX_PREAMBLE_LENGTH_;
	RF_InitStruct.TxPremClass = (RF_PMPATWD_Enum)_TX_PREAMBLE_CLASS_;
	RF_InitStruct.TxPremPattern = _TX_PREAMBLE_PATTERN_;	
	RF_InitStruct.SyncWordWidth = (RF_SYNCLEN_Enum)_SYNCWORD_WIDTH_;
	RF_InitStruct.TrailerField = (_TRAILER_FIELD_ != 0)?ENABLE:DISABLE;
	RF_InitStruct.HeadField = (RF_PLHF_Enum)_HEAD_WIDTH_;
	RF_InitStruct.LengthField = (_LENGTH_FIELD_ != 0)?ENABLE:DISABLE;
	RF_InitStruct.CRCField = (RF_CRCFMT_Enum)_CRC_FIELD_;
	RF_InitStruct.CRCInv = (RF_CRCPOL_Enum)_CRC_INVERTED_;
	RF_InitStruct.CRCBitOD = (RF_BITOD_Enum)_CRC_BIT_ORDER_;
	RF_InitStruct.CRCByteOD = (RF_BYTEOD_Enum)_CRC_BYTE_ORDER_;
	RF_InitStruct.CRCSeed = _CRC_SEED_;	
	RF_InitStruct.ManchesterCode = (_MANCHESTER_CODE_ != 0)?ENABLE:DISABLE;
	RF_InitStruct.HammingCode = (_HAMMING_CODE_ != 0)?ENABLE:DISABLE;
	RF_InitStruct.HeadAddrExamine = (_EXAMINE_PLHAC_ != 0)?ENABLE:DISABLE;
	RF_InitStruct.WhiteningCodec = (RF_WHTFMT_Enum)_WHITENING_CODEC_;
	RF_InitStruct.WhiteningSeed = _WHITENING_SEED_;
	RF_InitStruct.ReceiverMode = (_RECEIVER_MODE_ != 0)?RECEIVER_CONTINUE:RECEIVER_SINGLE;
	RF_InitStruct.AutomaticACK = (_AUTOMATIC_ACK_ != 0)?ENABLE:DISABLE;
	RF_InitStruct.TimeUnit = (RF_ATRTU_Enum)_ATRK_TIME_UNIT_;
	
	/* RF enter light sleep */
	BC3603_EnterLightSleep();	
	/* wait crystal ready */
	if(BC3603_WaitCrystalReady() != SUCCESS)	return(ERROR);
	/* RF set crysatal tune */
	BC3603_SetCrystalCload(_CYL_COARSE_TUNE_,_CYL_FINE_TUNE_);
	/* RF packet */
	if(BC3603_Configures(&RF_InitStruct) != SUCCESS) return(ERROR);
	BC3603_SetReceiverLength(_RECEIVER_PDLEN_);
	BC3603_SetHeaderAddress(_HEAD_ADDRESS_);	
	
	/* RF SYNC */
	*((u16 *)(&Syncw[0])) = _SYNCWORD_LOW_ & 0xFFFF;
	*((u16 *)(&Syncw[2])) = _SYNCWORD_LOW_ >> 16;
	*((u16 *)(&Syncw[4])) = _SYNCWORD_HIGH_ & 0xFFFF;
	*((u16 *)(&Syncw[6])) = _SYNCWORD_HIGH_ >> 16;
#if	(_SYNCWORD_BCH_ == 1)
	BCH_SyncwordCalculate(RF_InitStruct.SyncWordWidth,Syncw,SyncBch);
	BC3603_SetSyncWord(SyncBch,SYNCWORD_MAX_SIZE);
#else
	BC3603_SetSyncWord(Syncw,SYNCWORD_MAX_SIZE);	
#endif
	/* LIRC calibartion */
	if(BC3603_LIRCCalibration() == ERROR) return(ERROR);
	/* enter deep sleep */
	BC3603_EnterDeepSleep();	
	return(SUCCESS);
}
/*****************************************************************************************************
* @brief  carrier test item initial.
* @retval None
*******************************************************************************************************/
ErrStatus BC3603_ParameterUpdate(void)	
{
	return(SUCCESS);
}

/*****************************************************************************************************
* @brief  Is the two buffer data same ?
* @retval None
*******************************************************************************************************/
bool is_same_data(u8 *saddr,u8 *taddr,u32 len)
{
	u8	i;
	for(i=0; i<len; i++)
	{
		if(*(taddr+i) != *(saddr+i))
			return FALSE;
	}
	return TRUE;
}

/*****************************************************************************************************
* @brief  LCM display initial.
* @retval None
*******************************************************************************************************/
const char LCM_DR_SHOW[][4]=
{
	"  2",
	" 10",
	" 50",
	"125",
	"250",
};
const char LCM_BAND_SHOW[][4]=
{
	"315",
	"433",
	"470",
	"868",
	"915",
};
void LCM_Display_Init(void)	
{
	lcm_put8x8_string((s8 *)"ATR_Mode",0,0,DSP_NORMAL);
	lcm_put8x8_string((s8 *)">>WOR",1,11,DSP_NORMAL); 
	
	lcm_put8x8_string((s8 *)"000MHz | 000kbps",2,0,DSP_NORMAL); 
	lcm_put8x8_string((s8 *)LCM_BAND_SHOW[_RF_FREQ_BAND_],2,0,DSP_NORMAL); 
	lcm_put8x8_string((s8 *)LCM_DR_SHOW[_RF_DATA_RATE_],2,9,DSP_NORMAL); 
	
	LCM_Display_Updata();	
	
	// RUN status
	lcm_put8x8_string((s8 *)"STOP",7,12,DSP_INVERT);
}

/*****************************************************************************************************
* @brief  LCM display updata
* @retval None
*******************************************************************************************************/
void LCM_Display_Updata(void)	
{
	u8 lcm_buffer[22];

	// rx success counter & rx fail counter
	sprintf((char *)lcm_buffer,"Rx:%04d Err:%04d",RadioParam.rx_success_number,RadioParam.rx_fail_number);
	lcm_put8x8_string((s8 *)lcm_buffer,4,0,DSP_NORMAL);
	sprintf((char *)lcm_buffer,"Wk:%04d Det:%04d",RadioParam.rx_wakeup_number,RadioParam.rx_detect_number);
	lcm_put8x8_string((s8 *)lcm_buffer,5,0,DSP_NORMAL);
	// rx receive packet rssi
	sprintf((char *)lcm_buffer,"Rssi:-%03d",RadioParam.rx_rcv_rssi);
	lcm_put8x8_string((s8 *)lcm_buffer,6,0,DSP_NORMAL);
	
	
	lcm_put8x8_string((s8 *)"    ",7,12,DSP_NORMAL);
	if(mflag.bits.rf_wor)
		lcm_put8x8_string((s8 *)"RUN",7,13,DSP_INVERT);
	else
		lcm_put8x8_string((s8 *)"STOP",7,12,DSP_INVERT); 
}

/*****************************************************************************************************
* @brief  calculation time for wor rxap proc
* @retval None
*******************************************************************************************************/
u32 cal_wor_min_rxap_us(void)
{
	u32	result=0;
	float uint;
	
	if(_RF_DATA_RATE_ == DATARATE2K)
		uint = (float)1000/2;
	if(_RF_DATA_RATE_ == DATARATE10K)
		uint = (float)1000/10;
	if(_RF_DATA_RATE_ == DATARATE50K)
		uint = (float)1000/50;
	if(_RF_DATA_RATE_ == DATARATE125K)
		uint = (float)1000/125;
	if(_RF_DATA_RATE_ == DATARATE250K)
		uint = (float)1000/250;
	
	result = (float)((_SYNCWORD_WIDTH_+3)*8*uint)+500;
	
	return result;
}

/*********************************************************************************************************
 * @brief   This function handles WAKE UP interrupt.
 * @retval  None
 ************************************************************************************************************/
#if (_MCU_SLEEP_MODE_ != 0)
void WKUP_IRQHandler(void)
{
	NVIC_ClearPendingIRQ(EVWUP_IRQn);
	NVIC_DisableIRQ(EVWUP_IRQn);
  /*--------------------------------------------------------------------------------------------------------*/
  /* DSB instruction is added in this function to ensure the write operation which is for clearing interrupt*/
  /* flag is actually completed before exiting ISR. It prevents the NVIC from detecting the interrupt again */
  /* since the write register operation may be pended in the internal write buffer of Cortex-Mx when program*/
  /* has exited interrupt routine. This DSB instruction may be masked if this function is called in the     */
  /* beginning of ISR and there are still some instructions before exiting ISR.                             */
  /*--------------------------------------------------------------------------------------------------------*/
  __DSB();
}
#endif
/*****************************************************************************************************
* @brief  Configures the system clocks.
* @retval None
*******************************************************************************************************/
void MCU_gpio_Configuration(void)
{
#if	(MDEBIO_ENABLE == 1)
	AFIO_GPxConfig(MDBIO_P0_AFIO_PORT, MDBIO_P0, MDBIO_P0_AFIO_FUN);
	AFIO_GPxConfig(MDBIO_P1_AFIO_PORT, MDBIO_P1, MDBIO_P1_AFIO_FUN);

	GPIO_DirectionConfig(MDBIO_P0_PORT,MDBIO_P0,GPIO_DIR_OUT);
	MDBIO_P0_CLR();
	GPIO_DirectionConfig(MDBIO_P1_PORT,MDBIO_P1,GPIO_DIR_OUT);
	MDBIO_P1_CLR();
#endif	
}

/*******************************************************************************************************
 * @brief  Configures the system clocks.
 * @retval None
 *******************************************************************************************************/
/*
//  <h> Clock Control Configuration
//  	<h> Communication
//    	<q0.12> EBI
//    	<q1.0> I2C0		<q1.1> I2C1
//    	<q1.25> I2S
//    	<q1.24> SCI0	<q1.27> SCI1
//    	<q1.4> SPI0 	<q1.5> SPI1
//    	<q1.8> USART0	<q1.9> USART1
//    	<q1.10> UART0  <q1.11> UART1
//    	<q0.10>  USB
//  	</h>
//  	<h> IO
//    	<q0.16> GPIO Port A <q0.17>  GPIO Port B <q0.18>  GPIO Port C <q0.19>  GPIO Port D
//    	<q1.14> AFIO
//    	<q1.15> EXTI
//  	</h>
//  	<h> System
//    	<q2.24> ADC
//    	<q0.11> CKREF
//    	<q0.13>  CRC
//    	<q2.22> CMP
//    	<q0.4>  PDMA
//    	<q2.6> PWRCU
//  	</h>
//  	<h> Timer
//    	<q2.16> BFTM0 <q2.17> BFTM1
//    	<q2.28> SCTM0 <q2.29> SCTM1 <q2.30> SCTM2 <q2.31> SCTM3
//    	<q2.8> GPTM0 <q2.9> GPTM1
//    	<q2.0> MCTM0
//    	<q2.6> RTC   <q2.4> WDT
//  	</h>
//  </h>
*/
#define	_CKCU_AHBCCR_		(0x000F2810)
#define	_CKCU_APBCR0_		(0x0000CF33)
#define	_CKCU_APBCR1_		(0xF1430341)

void CKCU_Configuration(void)
{
	CKCU_PeripClockConfig_TypeDef cken;
  
   /* APB Peripheral Clock Selection to CK_AHB or CK_AHB/4 */
   HT_CKCU->APBPCSR0 = 0;           /* Reset value of APBPCSR0   */
   HT_CKCU->APBPCSR1 = 0;           /* Reset value of APBPCSR1   */ 

   /* Configure the CK_ADC prescaler(CK_ADC) = HCLK / 1 */
   CKCU_SetADCPrescaler(CKCU_ADCPRE_DIV1);   
	/* Configure the AHB/APB clock control */
	cken.Reg[0] = _CKCU_AHBCCR_;
	cken.Reg[1] = _CKCU_APBCR0_;
	cken.Reg[2] = _CKCU_APBCR1_;	
   CKCU_PeripClockConfig(cken,ENABLE);   
}

